@@ -1,5 +1,6 @@
 from tsdoc0.python.comment_sentence import CommentSentence
 from tsdoc0.python.model import Model
+from tsdoc0.python.utils import repr_parent
 from tsdoc0.python.segment import Segment
 from typing import Final
 from typing import Iterable
@@ -17,7 +18,7 @@ def _tuple(iterable: Iterable[CommentSentence]) -> Tuple[CommentSentence, ...]:
 
 @attr.s(auto_attribs=True, kw_only=True)
 class CommentAbstract(Segment):
-    parent: Optional[Model] = attr.ib(eq=False)
+    parent: Optional[Model] = attr.ib(eq=False, repr=repr_parent)
     indentation: Final[str]  # type: ignore[misc]
     sentences: Final[Tuple[CommentSentence, ...]] = attr.ib(converter=_tuple)
 
