@@ -34,6 +34,8 @@ class VocabularyTerm(Segment):
     def definition(self) -> str:
         definitions = {
             "and operator": "True if all parts are True",
+            "Animation": "Rapid changes that the human eye perceives as motion",
+            "Animation rate": "Attribute that controls how fast the images from a spritesheet change",  # noqa: E501
             "Argument": "Information that a function needs to know in order to run",
             "Assignment": "Storing information in a variable",
             "Attribute": "A piece of information an object knows about itself",
@@ -42,6 +44,7 @@ class VocabularyTerm(Segment):
             "break statement": "Immediately end a loop",
             "Chained comparison": "An expression with more than one comparison operator",  # noqa: E501
             "Class": "A blueprint for creating something specific",
+            "Collision": "When sprites touch or overlap",
             "Comment": "A note that the computer ignores",
             "Comparison operator": "Compares two values and gives a yes or no answer",
             "Compound assignment operator": "Changes a variable based on the current value",  # noqa: E501
@@ -54,14 +57,18 @@ class VocabularyTerm(Segment):
             "Data type": "The category a piece of information belongs to",
             "Decrement": "Decrease a variable by an amount",
             "Documentation": "A written explanation of how to use code",
+            "Duration": "The amount of time between two moments",
             "elif clause": "When all prior conditions are false, runs a section of code when the condition is true",  # noqa: E501
             "else clause": "When all prior conditions are false, runs a section of code as a last alternative",  # noqa: E501
             "Equal to": "Are the two values the same?",
             "Error": "When the computer encounters something unexpected in your code",  # noqa: E501
+            "Event": "A single action that occurs as a result of the user",  # noqa: E501
             "Exponentiation operator": "Multiplies a number by itself some number of times",  # noqa: E501
             "Expression": "A piece of code that produces a value",
             "Float": "A number with a decimal point",
             "Floor division operator": "Rounds the quotient down to a whole number after division",  # noqa: E501
+            "For loop": "A loop that runs a specific number of times",  # noqa: E501
+            "Frame": "One still image within an animation, usually one iteration of a loop",  # noqa: E501
             "Function": "A named code action that can be used in a program",
             "Greater than": "Is the left value bigger than the right value?",
             "Header comment": 'A multi-line comment at the top of a program surrounded by `"""` marks',  # noqa: E501
@@ -70,15 +77,19 @@ class VocabularyTerm(Segment):
             "Infinite loop": "A loop with a condition that will always be True",
             "Instance": "A specific copy created from a class",
             "Integer": "A whole number",
+            "Interaction": "A cycle of user input and program output that influence each other",  # noqa: E501
             "Iteration": "One repetition of a loop",
+            "Key constant": "An unchanging value representing a key on the keyboard",
             "Less than": "Is the left value smaller than the right value?",
             "Library": "A collection of code from outside the program",
             "Literal": "A value you can literally see",
             "Logical operator": "Combines or modifies a boolean",
             "Loop else clause": "A clause following a loop that runs unless the loop ends with break",  # noqa: E501
+            "Loop variable": "A variable whose value changes based on the iteration of a loop",  # noqa: E501
             "Main loop": "Keeps a window open and updated",
             "Method": "A function that belongs to an instance",
             "Modulo operator": "Calculates the remainder after division",
+            "Multiple assignment": "Assigning more than one variable with the same operator",  # noqa: E501
             "Nested conditional": "A conditional inside another conditional",
             "None": 'A special literal that means "no value"',
             "Not equal to": "Are the two values different?",
@@ -86,9 +97,15 @@ class VocabularyTerm(Segment):
             "or operator": "True if one or more parts are True",
             "Output": "Information a program gives to the user, such as text",
             "random library": "A library with code to create unpredictable values",
+            "Range": "A sequence of integers with a start and an end",
             "Return value": "Information given back by a function",
+            "Speed": "Attributes that control how fast and what direction an instance moves on screen",  # noqa: E501
             "Sprite": "An on-screen graphic based on an image",
+            "Spritesheet": "An image designed to be broken apart and used as an animation",  # noqa: E501
+            "State": "Information that is remembered by the program",
             "Statement": "A single line of code that performs an action",
+            "Start": "The first value in a range",
+            "Step": "The amount that a range counts by",
             "String": "A group of letters, symbols and/or numbers inside double quotation marks",  # noqa: E501
             "String concatenation": "Join two strings together with the + operator",
             "String multiplication": "Repeat a string a certain number of times with the * operator",  # noqa: E501
@@ -109,6 +126,8 @@ class VocabularyTerm(Segment):
     def instruction(self) -> str:
         instructions = {
             "and operator": "2.4.1",
+            "Animation": "3.5.1",
+            "Animation rate": "3.5.1",
             "Argument": "1.2.1",
             "Assignment": "1.1.3",
             "Attribute": "3.3.1",
@@ -117,6 +136,7 @@ class VocabularyTerm(Segment):
             "break statement": "3.2.1",
             "Chained comparison": "2.2.2",
             "Class": "3.3.1",
+            "Collision": "3.6.2",
             "Comment": "1.1.2",
             "Comparison operator": "2.1.2",
             "Compound assignment operator": "1.4.1",
@@ -129,14 +149,18 @@ class VocabularyTerm(Segment):
             "Data type": "1.3.1",
             "Decrement": "1.4.1",
             "Documentation": "1.2.2",
+            "Duration": "3.6.1",
             "elif clause": "2.2.1",
             "else clause": "2.2.1",
             "Equal to": "2.1.1",
             "Error": "1.1.2",
+            "Event": "3.6.1",
             "Exponentiation operator": "2.3.2",
             "Expression": "1.4.1",
             "Float": "1.3.1",
             "Floor division operator": "2.3.2",
+            "For loop": "3.7.1",
+            "Frame": "3.5.1",
             "Function": "1.2.1",
             "Greater than": "2.1.2",
             "Header comment": "1.1.2",
@@ -145,15 +169,19 @@ class VocabularyTerm(Segment):
             "Infinite loop": "3.1.1",
             "Instance": "3.3.1",
             "Integer": "1.3.1",
+            "Interaction": "3.6.1",
             "Iteration": "3.1.1",
+            "Key constant": "3.6.1",
             "Less than": "2.1.2",
             "Library": "1.2.1",
             "Literal": "1.3.1",
             "Logical operator": "2.4.1",
             "Loop else clause": "3.2.1",
+            "Loop variable": "3.7.1",
             "Main loop": "3.4.1",
             "Method": "3.3.1",
             "Modulo operator": "2.3.2",
+            "Multiple assignment": "3.6.2",
             "Nested conditional": "2.2.2",
             "None": "1.4.2",
             "Not equal to": "2.1.1",
@@ -161,9 +189,15 @@ class VocabularyTerm(Segment):
             "or operator": "2.4.1",
             "Output": "1.1.1",
             "random library": "2.3.1",
+            "Range": "3.7.1",
             "Return value": "1.4.2",
+            "Speed": "3.5.1",
             "Sprite": "3.4.1",
+            "Spritesheet": "3.5.1",
             "Statement": "1.1.1",
+            "State": "3.6.1",
+            "Start": "3.7.2",
+            "Step": "3.7.2",
             "String": "1.1.1",
             "String concatenation": "1.3.2",
             "String multiplication": "1.3.2",
